==> uniq-1.2.0.25-py3-none-any.whl: uniq/apis/nb/clients/inventory_manager_client/models/CLICredentialDTO.py <==
#!/usr/bin/env python
#pylint: skip-file
"""
Copyright 2016 Cisco Systems

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
"""

class CLICredentialDTO(object):



    def __init__(self):
        """
        Attributes:
          swaggerTypes (dict): The key is attribute name and the value is attribute type.
          attributeMap (dict): The key is attribute name and the value is json key in definition.
        """
        self.swaggerTypes = {

            'username': 'str',


            'enablePassword': 'str',


            'password': 'str',


            'description': 'str',


            'comments': 'str',


            'credentialType': 'str',


            'instanceUuid': 'str'

        }

        self.attributeMap = {

            'username': 'username',

            'enablePassword': 'enablePassword',

            'password': 'password',

            'description': 'description',

            'comments': 'comments',

            'credentialType': 'credentialType',

            'instanceUuid': 'instanceUuid'

        }



        self.username = None # str


        self.enablePassword = None # str


        self.password = None # str


        self.description = None # str


        self.comments = None # str


        self.credentialType = None # str


        self.instanceUuid = None # str

==> uniq-1.3.2.30-py3-none-any.whl: uniq/apis/nb/clients/inventory_manager_client/models/CLICredentialDTO.py <==
#!/usr/bin/env python
#pylint: skip-file
# This source code is licensed under the Apache license found in the
# LICENSE file in the root directory of this project.


class CLICredentialDTO(object):


    def __init__(self):
        """
        Attributes:
          swaggerTypes (dict): The key is attribute name and the value is attribute type.
          attributeMap (dict): The key is attribute name and the value is json key in definition.
        """
        self.swaggerTypes = {
            
            'username': 'str',
            
            
            'enablePassword': 'str',
            
            
            'password': 'str',
            
            
            'description': 'str',
            
            
            'credentialType': 'str',
            
            
            'comments': 'str',
            
            
            'instanceUuid': 'str',
            
            
            'id': 'str'
            
        }

        self.attributeMap = {
            
            'username': 'username',
            
            'enablePassword': 'enablePassword',
            
            'password': 'password',
            
            'description': 'description',
            
            'credentialType': 'credentialType',
            
            'comments': 'comments',
            
            'instanceUuid': 'instanceUuid',
            
            'id': 'id'
            
        }       

        
        #CLI username
        
        self.username = None # str
        
        #CLI enable password
        
        self.enablePassword = None # str
        
        #CLI password
        
        self.password = None # str
        
        #Description of the credential
        
        self.description = None # str
        
        #Credential type to identify the application that uses the credential
        
        self.credentialType = None # str
        
        #Comments to identify the credential
        
        self.comments = None # str
        
        
        self.instanceUuid = None # str
        
        
        self.id = None # str
